
"""

Microblog feature index

"""

SEND = 0
RECEIVE = 1
SEARCH = 2
REPLY = 3
RESPONSES = 4
DELETE = 5
THREAD = 6
THREAD_REPLY = 7
TAG = 8
GROUP = 9
SEARCH_URL = 10
USER_MESSAGES = 11
READ = 12
RETWEET = 13
LIKE = 14
GEO_FRIEND_POSITIONS = 50
